@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemManager.php 5734 2013-02-26 00:56:33Z fishbone $
+ * @version    SVN: $Id: systemManager.php 5878 2013-03-30 08:41:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');		// Magic3コアクラス
@@ -54,6 +54,7 @@ class SystemManager extends Core
 	const CF_DEFAULT_TEMPLATE_MOBILE	= 'mobile_default_template';	// システム定義値取得用キー(携帯用デフォルトテンプレート)
 	const CF_DEFAULT_TEMPLATE_SMARTPHONE	= 'smartphone_default_template';	// システム定義値取得用キー(スマートフォン用デフォルトテンプレート)
 	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
+	const CF_DEFAULT_THEME = 'default_theme';		// 一般画面用jQueryUIテーマ
 	const CF_ACCEPT_LANGUAGE	= 'accept_language';	// アクセス可能言語
 	const CF_ADMIN_DEFAULT_TEMPLATE = 'admin_default_template';		// 管理用デフォルトテンプレート
 	const CF_MOBILE_AUTO_REDIRECT = 'mobile_auto_redirect';		// 携帯の自動遷移
@@ -396,6 +397,18 @@ class SystemManager extends Core
 		}
 		return $this->adminDefaultTheme;
 	}
+	/**
+	 * 一般画面用jQueryUIテーマを取得
+	 *
+	 * @return string	jQueryUIテーマ
+	 */
+	function defaultTheme()
+	{
+		static $theme;
+
+		if (!isset($theme)) $theme = $this->getSystemConfig(self::CF_DEFAULT_THEME);
+		return $theme;
+	}
 	/**
 	 * デフォルト言語以外のサイト定義を読み込む
 	 *
@@ -630,5 +643,22 @@ class SystemManager extends Core
 		}
 		return $this->hierarchicalPage;
 	}
+	/**
+	 * メインコンテンツタイプを取得
+	 *
+	 * @return array	コンテンツタイプ
+	 */
+	public function getAllContentType()
+	{
+		$contentType = array(	M3_VIEW_TYPE_CONTENT,				// 汎用コンテンツ
+								M3_VIEW_TYPE_PRODUCT,				// 製品
+								M3_VIEW_TYPE_BBS,					// BBS
+								M3_VIEW_TYPE_BLOG,				// ブログ
+								M3_VIEW_TYPE_WIKI,				// wiki
+								M3_VIEW_TYPE_USER,				// ユーザ作成コンテンツ
+								M3_VIEW_TYPE_EVENT,				// イベント
+								M3_VIEW_TYPE_PHOTO);				// フォトギャラリー
+		return $contentType;
+	}
 }
 ?>
